@@ -17,13 +17,14 @@ package PostScript::Report;
 # ABSTRACT: Produce formatted reports in PostScript
 #---------------------------------------------------------------------
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
+# This file is part of PostScript-Report 0.10 (April 4, 2012)
 
 use 5.008;
-use Moose;
+use Moose 0.90;                 # Moose::Meta::Attribute::Native
 use MooseX::Types::Moose qw(ArrayRef Bool CodeRef HashRef Int Num Str);
 use PostScript::Report::Types ':all';
-use PostScript::File 2.10 'pstr'; # Use improved API
+use PostScript::File 2.20 'pstr'; # Use function library
 
 use PostScript::Report::Font ();
 use List::Util 'min';
@@ -101,7 +102,7 @@ sub _init
 {
   my ($self) = @_;
 
-  $self->_set_ps( $self->_build_ps );
+  $self->_set_ps( my $ps = $self->_build_ps );
 
   foreach my $sectionName ($self->_sections) {
     my $section = $self->$sectionName or next;
@@ -109,41 +110,14 @@ sub _init
     $section->_set_height($self->row_height) unless $section->has_height;
   } # end foreach $sectionName
 
+  $ps->use_functions(qw(drawBox));
+
   $self->ps_functions->{+__PACKAGE__} = <<'END PS';
-%---------------------------------------------------------------------
-% Create a rectangular path:  Left Top Right Bottom boxpath
-
-/boxpath
-{
-  % stack L T R B
-  newpath
-  2 copy moveto                 % move to BR
-  3 index exch lineto	        % line to BL
-  % stack L T R
-  1 index
-  % stack L T R T
-  4 2 roll
-  % stack R T L T
-  lineto                        % line to TL
-  lineto                        % line to TR
-  closepath
-} bind def
-
-%---------------------------------------------------------------------
-% Clip to a rectangle:   Left Top Right Bottom clipbox
-
-/clipbox { boxpath clip } bind def
-
-%---------------------------------------------------------------------
-% Draw a rectangle:   Left Top Right Bottom drawbox
-
-/drawbox { boxpath stroke } bind def
-
 %---------------------------------------------------------------------
 % Draw border styles: Left Top Right Bottom Linewidth dbX
 
 /db0 { 5 { pop } repeat } bind def
-/db1 { gsave setlinewidth drawbox grestore } bind def
+/db1 { gsave setlinewidth drawBox grestore } bind def
 
 % Easy access to the corners of a box:
 % 3 3 1 1
@@ -182,93 +156,6 @@ sub _init
 /dbTBL { bdrB  boxRT moveto  boxLT lineto  boxLB lineto  boxRB bdrE } bind def
 /dbTBR { bdrB  boxLT moveto  boxRT lineto  boxRB lineto  boxLB bdrE } bind def
 
-%---------------------------------------------------------------------
-% Set the color:  RGBarray|BWnumber setColor
-
-/setColor
-{
-  dup type (arraytype) eq {
-    % We have an array, so it's RGB:
-    aload pop
-    setrgbcolor
-  }{
-    % Otherwise, it must be a gray level:
-    setgray
-  } ifelse
-} bind def
-
-%---------------------------------------------------------------------
-% Fill a box with color:  Left Top Right Bottom Color fillbox
-
-/fillbox
-{
-  gsave
-  setColor
-  boxpath
-  fill
-  grestore
-} bind def
-
-%---------------------------------------------------------------------
-% Print text centered at a point:  X Y STRING showcenter
-%
-% Centers text horizontally
-
-/showcenter
-{
-  newpath
-  0 0 moveto
-  % stack X Y STRING
-  dup 4 1 roll                          % Put a copy of STRING on bottom
-  % stack STRING X Y STRING
-  false charpath flattenpath pathbbox   % Compute bounding box of STRING
-  % stack STRING X Y Lx Ly Ux Uy
-  pop exch pop                          % Discard Y values (... Lx Ux)
-  add 2 div neg                         % Compute X offset
-  % stack STRING X Y Ox
-  0                                     % Use 0 for y offset
-  newpath
-  moveto
-  rmoveto
-  show
-} bind def
-
-%---------------------------------------------------------------------
-% Print left justified text:  X Y STRING showleft
-%
-% Does not adjust vertical placement.
-
-/showleft
-{
-  newpath
-  3 1 roll  % STRING X Y
-  moveto
-  show
-} bind def
-
-%---------------------------------------------------------------------
-% Print right justified text:  X Y STRING showright
-%
-% Does not adjust vertical placement.
-
-/showright
-{
-  newpath
-  0 0 moveto
-  % stack X Y STRING
-  dup 4 1 roll                          % Put a copy of STRING on bottom
-  % stack STRING X Y STRING
-  false charpath flattenpath pathbbox   % Compute bounding box of STRING
-  % stack STRING X Y Lx Ly Ux Uy
-  pop exch pop                          % Discard Y values (... Lx Ux)
-  add neg                               % Compute X offset
-  % stack STRING X Y Ox
-  0                                     % Use 0 for y offset
-  newpath
-  moveto
-  rmoveto
-  show
-} bind def
 END PS
 } # end _init
 #---------------------------------------------------------------------
@@ -778,7 +665,7 @@ sub _attach_ps_resources
     $version = eval { $1->VERSION } if $key =~ /^([\w:]+)/;
 
     (my $name = $key) =~ s/:/_/g;
-    $ps->add_function($name, $funcs->{$key}, $version);
+    $ps->add_procset($name, $funcs->{$key}, $version);
   } # end foreach $key
 
   %$funcs = ();                 # Clear out ps_functions
@@ -910,9 +797,9 @@ PostScript::Report - Produce formatted reports in PostScript
 
 =head1 VERSION
 
-This document describes version 0.09 of
-PostScript::Report, released May 5, 2011
-as part of PostScript-Report version 0.09.
+This document describes version 0.10 of
+PostScript::Report, released April 4, 2012
+as part of PostScript-Report version 0.10.
 
 =head1 SYNOPSIS
 
@@ -1327,10 +1214,10 @@ Unicode in PostScript is non-trivial.
 
 Christopher J. Madsen  S<C<< <perl AT cjmweb.net> >>>
 
-Please report any bugs or feature requests to
-S<C<< <bug-PostScript-Report AT rt.cpan.org> >>>,
+Please report any bugs or feature requests
+to S<C<< <bug-PostScript-Report AT rt.cpan.org> >>>
 or through the web interface at
-L<http://rt.cpan.org/Public/Bug/Report.html?Queue=PostScript-Report>
+L<< http://rt.cpan.org/Public/Bug/Report.html?Queue=PostScript-Report >>.
 
 You can follow or contribute to PostScript-Report's development at
 L<< http://github.com/madsen/postscript-report >>.
@@ -1344,7 +1231,7 @@ It wouldn't have happened without them.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Christopher J. Madsen.
+This software is copyright (c) 2012 by Christopher J. Madsen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
