@@ -17,7 +17,8 @@ package PostScript::Report::Checkbox;
 # ABSTRACT: A checkbox with no label
 #---------------------------------------------------------------------
 
-our $VERSION = '0.01';
+our $VERSION = '0.10';
+# This file is part of PostScript-Report 0.10 (April 4, 2012)
 
 use Moose;
 use MooseX::Types::Moose qw(Bool Int Num Str);
@@ -70,6 +71,8 @@ after init => sub {
   $self->width( $self->size + 2 * $self->padding_side )
       unless $self->has_width;
 
+  $report->ps->use_functions('drawBox');
+
   # Use __PACKAGE__ instead of blessed $self because the string is
   # constant.  Subclasses should either use sub id { 'Checkbox' } or
   # define their own comparable functions:
@@ -84,7 +87,7 @@ after init => sub {
   translate			% SIZE VALUE
   0  2 index			% SIZE VALUE L T
   dup  0			% SIZE VALUE L T R B
-  drawbox			% SIZE VALUE
+  drawBox			% SIZE VALUE
   {				% SIZE
     600 div  dup  scale		% stack empty
     newpath
@@ -140,9 +143,9 @@ PostScript::Report::Checkbox - A checkbox with no label
 
 =head1 VERSION
 
-This document describes version 0.01 of
-PostScript::Report::Checkbox, released May 5, 2011
-as part of PostScript-Report version 0.09.
+This document describes version 0.10 of
+PostScript::Report::Checkbox, released April 4, 2012
+as part of PostScript-Report version 0.10.
 
 =head1 DESCRIPTION
 
@@ -181,10 +184,10 @@ No bugs have been reported.
 
 Christopher J. Madsen  S<C<< <perl AT cjmweb.net> >>>
 
-Please report any bugs or feature requests to
-S<C<< <bug-PostScript-Report AT rt.cpan.org> >>>,
+Please report any bugs or feature requests
+to S<C<< <bug-PostScript-Report AT rt.cpan.org> >>>
 or through the web interface at
-L<http://rt.cpan.org/Public/Bug/Report.html?Queue=PostScript-Report>
+L<< http://rt.cpan.org/Public/Bug/Report.html?Queue=PostScript-Report >>.
 
 You can follow or contribute to PostScript-Report's development at
 L<< http://github.com/madsen/postscript-report >>.
@@ -198,7 +201,7 @@ It wouldn't have happened without them.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Christopher J. Madsen.
+This software is copyright (c) 2012 by Christopher J. Madsen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
