@@ -17,7 +17,8 @@ package PostScript::Report::LinkField;
 # ABSTRACT: A field that can contain hyperlinks
 #---------------------------------------------------------------------
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
+# This file is part of PostScript-Report 0.10 (April 4, 2012)
 
 use Moose;
 use MooseX::Types::Moose qw(Bool Int Num Str);
@@ -83,6 +84,8 @@ has underline => (
 after init => sub {
   my ($self, $parent, $report) = @_;
 
+  $report->ps->use_functions(qw(clipBox));
+
   # Use __PACKAGE__ instead of blessed $self because the string is
   # constant.  Subclasses should either use sub id { 'LinkField' } or
   # define their own comparable functions:
@@ -91,7 +94,7 @@ after init => sub {
 % PROC X Y FONT L T R B LinkField
 
 /LinkField {
-  gsave clipbox setfont translate 0 0 moveto exec grestore
+  gsave clipBox setfont translate 0 0 moveto exec grestore
 } bind def
 
 % STRING Yoff LinkField-UL
@@ -250,9 +253,9 @@ PostScript::Report::LinkField - A field that can contain hyperlinks
 
 =head1 VERSION
 
-This document describes version 0.09 of
-PostScript::Report::LinkField, released May 5, 2011
-as part of PostScript-Report version 0.09.
+This document describes version 0.10 of
+PostScript::Report::LinkField, released April 4, 2012
+as part of PostScript-Report version 0.10.
 
 =head1 DESCRIPTION
 
@@ -322,10 +325,10 @@ No bugs have been reported.
 
 Christopher J. Madsen  S<C<< <perl AT cjmweb.net> >>>
 
-Please report any bugs or feature requests to
-S<C<< <bug-PostScript-Report AT rt.cpan.org> >>>,
+Please report any bugs or feature requests
+to S<C<< <bug-PostScript-Report AT rt.cpan.org> >>>
 or through the web interface at
-L<http://rt.cpan.org/Public/Bug/Report.html?Queue=PostScript-Report>
+L<< http://rt.cpan.org/Public/Bug/Report.html?Queue=PostScript-Report >>.
 
 You can follow or contribute to PostScript-Report's development at
 L<< http://github.com/madsen/postscript-report >>.
@@ -339,7 +342,7 @@ It wouldn't have happened without them.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Christopher J. Madsen.
+This software is copyright (c) 2012 by Christopher J. Madsen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
